==> zio-aws-memorydb_3-5.17.112.1-sources.jar: zio/aws/memorydb/model/DescribeParameterGroupsResponse.scala <==
package zio.aws.memorydb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class DescribeParameterGroupsResponse(
    nextToken: Option[String] = None,
    parameterGroups: Option[Iterable[zio.aws.memorydb.model.ParameterGroup]] =
      None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.memorydb.model.DescribeParameterGroupsResponse = {
    import DescribeParameterGroupsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.memorydb.model.DescribeParameterGroupsResponse
      .builder()
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .optionallyWith(
        parameterGroups.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.parameterGroups)
      .build()
  }
  def asReadOnly
      : zio.aws.memorydb.model.DescribeParameterGroupsResponse.ReadOnly =
    zio.aws.memorydb.model.DescribeParameterGroupsResponse.wrap(buildAwsValue())
}
object DescribeParameterGroupsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.memorydb.model.DescribeParameterGroupsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.memorydb.model.DescribeParameterGroupsResponse =
      zio.aws.memorydb.model.DescribeParameterGroupsResponse(
        nextToken.map(value => value),
        parameterGroups.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def nextToken: Option[String]
    def parameterGroups
        : Option[List[zio.aws.memorydb.model.ParameterGroup.ReadOnly]]
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getParameterGroups: ZIO[Any, AwsError, List[
      zio.aws.memorydb.model.ParameterGroup.ReadOnly
    ]] = AwsError.unwrapOptionField("parameterGroups", parameterGroups)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.memorydb.model.DescribeParameterGroupsResponse
  ) extends zio.aws.memorydb.model.DescribeParameterGroupsResponse.ReadOnly {
    override val nextToken: Option[String] =
      scala.Option(impl.nextToken()).map(value => value: String)
    override val parameterGroups
        : Option[List[zio.aws.memorydb.model.ParameterGroup.ReadOnly]] = scala
      .Option(impl.parameterGroups())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.memorydb.model.ParameterGroup.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.memorydb.model.DescribeParameterGroupsResponse
  ): zio.aws.memorydb.model.DescribeParameterGroupsResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-memorydb_3-5.17.203.2-sources.jar: zio/aws/memorydb/model/DescribeParameterGroupsResponse.scala <==
package zio.aws.memorydb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class DescribeParameterGroupsResponse(
    nextToken: Optional[String] = Optional.Absent,
    parameterGroups: Optional[Iterable[zio.aws.memorydb.model.ParameterGroup]] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.memorydb.model.DescribeParameterGroupsResponse = {
    import DescribeParameterGroupsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.memorydb.model.DescribeParameterGroupsResponse
      .builder()
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .optionallyWith(
        parameterGroups.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.parameterGroups)
      .build()
  }
  def asReadOnly
      : zio.aws.memorydb.model.DescribeParameterGroupsResponse.ReadOnly =
    zio.aws.memorydb.model.DescribeParameterGroupsResponse.wrap(buildAwsValue())
}
object DescribeParameterGroupsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.memorydb.model.DescribeParameterGroupsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.memorydb.model.DescribeParameterGroupsResponse =
      zio.aws.memorydb.model.DescribeParameterGroupsResponse(
        nextToken.map(value => value),
        parameterGroups.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def nextToken: Optional[String]
    def parameterGroups
        : Optional[List[zio.aws.memorydb.model.ParameterGroup.ReadOnly]]
    def getNextToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getParameterGroups: ZIO[Any, AwsError, List[
      zio.aws.memorydb.model.ParameterGroup.ReadOnly
    ]] = AwsError.unwrapOptionField("parameterGroups", parameterGroups)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.memorydb.model.DescribeParameterGroupsResponse
  ) extends zio.aws.memorydb.model.DescribeParameterGroupsResponse.ReadOnly {
    override val nextToken: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => value: String)
    override val parameterGroups
        : Optional[List[zio.aws.memorydb.model.ParameterGroup.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.parameterGroups())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.memorydb.model.ParameterGroup.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.memorydb.model.DescribeParameterGroupsResponse
  ): zio.aws.memorydb.model.DescribeParameterGroupsResponse.ReadOnly =
    new Wrapper(impl)
}
